@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2024 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ namespace access_logic {
 
 int view_resources_role ()
 {
-  return Filter_Roles::consultant ();
+  return roles::consultant;
 }
 
 
@@ -45,7 +45,7 @@ bool privilege_view_resources (Webserver_Request& webserver_request, std::string
 
 int view_notes_role ()
 {
-  return Filter_Roles::consultant ();
+  return roles::consultant;
 }
 
 
@@ -60,7 +60,7 @@ bool privilege_view_notes (Webserver_Request& webserver_request, std::string use
 
 int create_comment_notes_role ()
 {
-  return Filter_Roles::consultant ();
+  return roles::consultant;
 }
 
 
@@ -75,7 +75,7 @@ bool privilege_create_comment_notes (Webserver_Request& webserver_request, std::
 
 int delete_consultation_notes_role ()
 {
-  return Filter_Roles::manager ();
+  return roles::manager;
 }
 
 
@@ -84,13 +84,13 @@ bool privilege_delete_consultation_notes (Webserver_Request& webserver_request,
   int level {0};
   user_level (webserver_request, user, level);
   if (level >= delete_consultation_notes_role ()) return true;
-  return webserver_request.database_config_user ()->getPrivilegeDeleteConsultationNotesForUser (user);
+  return webserver_request.database_config_user ()->get_privilege_delete_consultation_notes_for_user (user);
 }
 
 
 int use_advanced_mode_role ()
 {
-  return Filter_Roles::manager ();
+  return roles::manager;
 }
 
 
@@ -99,13 +99,13 @@ bool privilege_use_advanced_mode (Webserver_Request& webserver_request, std::str
   int level {0};
   user_level (webserver_request, user, level);
   if (level >= use_advanced_mode_role ()) return true;
-  return webserver_request.database_config_user ()->getPrivilegeUseAdvancedModeForUser (user);
+  return webserver_request.database_config_user ()->get_privilege_use_advanced_mode_for_user (user);
 }
 
 
 int set_stylesheets_role ()
 {
-  return Filter_Roles::manager ();
+  return roles::manager;
 }
 
 
@@ -114,7 +114,7 @@ bool privilege_set_stylesheets (Webserver_Request& webserver_request, std::strin
   int level {0};
   user_level (webserver_request, user, level);
   if (level >= set_stylesheets_role ()) return true;
-  return webserver_request.database_config_user ()->getPrivilegeSetStylesheetsForUser (user);
+  return webserver_request.database_config_user ()->get_privilege_set_stylesheets_for_user (user);
 }
 
 
