@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ std::string bible_import_url ()
 
 bool bible_import_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 }
 
 
@@ -76,9 +76,9 @@ std::string bible_import (Webserver_Request& webserver_request)
   }
 
   // USFM data submission.
-  if (webserver_request.post.count ("submit")) {
+  if (webserver_request.post_count("submit")) {
     // Submission may take long if there's a lot of data or the network is slow.
-    std::string data = webserver_request.post ["data"];
+    std::string data = webserver_request.post_get("data");
     data = filter_url_tag_to_plus (data);
     data = filter::strings::trim (data);
     if (!data.empty()) {
@@ -95,23 +95,39 @@ std::string bible_import (Webserver_Request& webserver_request)
       success_message = translate("Nothing was imported.");
     }
     // User imported something into this Bible: Set it as the default Bible.
-    webserver_request.database_config_user()->setBible (bible);
+    webserver_request.database_config_user()->set_bible (bible);
   }
 
-  // File upload.
-  if (webserver_request.post.count ("upload")) {
-    const std::string datafile = filter_url_tempfile () + webserver_request.post ["filename"];
-    const std::string data = webserver_request.post ["data"];
-    if (!data.empty ()) {
+  // Handle (multiple) file upload.
+  if (webserver_request.post_count("upload")) {
+    bool success {false};
+    std::string filename{};
+    std::string data{};
+    const auto upload = [&success, &bible, &book, &chapter, &filename, &data]() {
+      const std::string datafile = filter_url_tempfile() + filename;
       filter_url_file_put_contents (datafile, data);
+      tasks_logic_queue (task::import_bible, { datafile, bible, std::to_string (book), std::to_string (chapter) });
+      success = true;
+    };
+    for (const auto& [key, value] : webserver_request.post) {
+      if (key == "data")
+        data = value;
+      if (key == "filename")
+        filename = value;
+      if (!filename.empty() and !data.empty()) {
+        upload();
+        filename.clear();
+        data.clear();
+      }
+    }
+    if (success) {
       success_message = translate("Import has started.");
       view.set_variable ("journal", journal_logic_see_journal_for_progress ());
-      tasks_logic_queue (task::import_bible, { datafile, bible, std::to_string (book), std::to_string (chapter) });
     } else {
       error_message = translate ("Nothing was uploaded");
     }
     // User imported something into this Bible: Set it as the default Bible.
-    webserver_request.database_config_user()->setBible (bible);
+    webserver_request.database_config_user()->set_bible (bible);
   }
   
 #ifdef HAVE_UPLOAD
