@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -28,31 +28,27 @@
 #include <assets/header.h>
 #include <menu/logic.h>
 #include <checks/settings.h>
-using namespace std;
 
 
-string checks_settingspatterns_url ()
+std::string checks_settingspatterns_url ()
 {
   return "checks/settingspatterns";
 }
 
 
-bool checks_settingspatterns_acl ([[maybe_unused]] void * webserver_request)
+bool checks_settingspatterns_acl ([[maybe_unused]] Webserver_Request& webserver_request)
 {
 #ifdef HAVE_CLIENT
   return true;
 #else
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 #endif
 }
 
 
-string checks_settingspatterns (void * webserver_request)
+std::string checks_settingspatterns (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  
-  string page {};
+  std::string page {};
   Assets_Header header = Assets_Header (translate ("Patterns"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   header.add_bread_crumb (checks_settings_url (), menu_logic_checks_settings_text ());
@@ -60,18 +56,18 @@ string checks_settingspatterns (void * webserver_request)
   Assets_View view {};
   
   
-  string bible = access_bible::clamp (webserver_request, request->database_config_user()->getBible ());
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ());
   
   
-  if (request->post.count ("patterns")) {
-    string patterns = request->post ["patterns"];
-    if (!bible.empty ()) Database_Config_Bible::setCheckingPatterns (bible, patterns);
+  if (webserver_request.post_count("patterns")) {
+    const std::string patterns = webserver_request.post_get("patterns");
+    if (!bible.empty ()) database::config::bible::set_checking_patterns (bible, patterns);
     view.set_variable ("success", translate("The patterns were saved"));
   }
   
   
   view.set_variable ("bible", bible);
-  view.set_variable ("patterns", Database_Config_Bible::getCheckingPatterns (bible));
+  view.set_variable ("patterns", database::config::bible::get_checking_patterns (bible));
                                           
                                           
   page += view.render ("checks", "settingspatterns");
