@@ -27,57 +27,104 @@
 #include <database/bibleimages.h>
 #include <styles/logic.h>
 #include <locale/translate.h>
+#include <checks/issues.h>
 
 
 Checks_Usfm::Checks_Usfm (const std::string& bible)
 {
-  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
-  markers_stylesheet = database::styles1::get_markers (stylesheet);
-  for (const auto & marker : markers_stylesheet) {
-    database::styles1::Item style = database::styles1::get_marker_data (stylesheet, marker);
-    style_items [marker] = style;
-    int styleType = style.type;
-    int styleSubtype = style.subtype;
-
+  m_stylesheet = database::config::bible::get_export_stylesheet (bible);
+  markers_stylesheet = database::styles::get_markers (m_stylesheet);
+  for (const stylesv2::Style& style : stylesv2::styles) {
     // Find out which markers require an endmarker.
     // And which markers are embeddable.
     bool required_endmarker {false};
     bool embeddable_marker {false};
-    if (styleType == StyleTypeIdentifier) {
-      if (styleSubtype == IdentifierSubtypePublishedVerseMarker) {
+    switch (style.type) {
+      case stylesv2::Type::book_id:
+      case stylesv2::Type::usfm_version:
+      case stylesv2::Type::file_encoding:
+      case stylesv2::Type::remark:
+      case stylesv2::Type::running_header:
+        break;
+      case stylesv2::Type::long_toc_text:
+        long_toc1_marker = style.marker;
+        break;
+      case stylesv2::Type::short_toc_text:
+        short_toc2_marker = style.marker;
+        break;
+      case stylesv2::Type::book_abbrev:
+        abbrev_toc3_marker = style.marker;
+        break;
+      case stylesv2::Type::introduction_end:
+      case stylesv2::Type::title:
+      case stylesv2::Type::heading:
+      case stylesv2::Type::paragraph:
+      case stylesv2::Type::chapter:
+      case stylesv2::Type::chapter_label:
+      case stylesv2::Type::published_chapter_marker:
+        break;
+      case stylesv2::Type::alternate_chapter_number:
         required_endmarker = true;
-      }
-    }
-    if (styleType == StyleTypeFootEndNote) {
-      if ((styleSubtype == FootEndNoteSubtypeFootnote) || (styleSubtype == FootEndNoteSubtypeEndnote)) {
+        break;
+      case stylesv2::Type::verse:
+        break;
+      case stylesv2::Type::published_verse_marker:
+      case stylesv2::Type::alternate_verse_marker:
         required_endmarker = true;
-      }
-    }
-    if (styleType == StyleTypeCrossreference) {
-      if (styleSubtype == CrossreferenceSubtypeCrossreference) {
+        break;
+      case stylesv2::Type::table_row:
+      case stylesv2::Type::table_heading:
+      case stylesv2::Type::table_cell:
+        break;
+      case stylesv2::Type::footnote_wrapper:
+      case stylesv2::Type::endnote_wrapper:
         required_endmarker = true;
-      }
-    }
-    if (styleType == StyleTypeInlineText) {
-      required_endmarker = true;
-      embeddable_marker = true;
-    }
-    if (styleType == StyleTypeWordlistElement) {
-      required_endmarker = true;
-      embeddable_marker = true;
+        break;
+      case stylesv2::Type::note_standard_content:
+      case stylesv2::Type::note_content:
+        break;
+      case stylesv2::Type::note_content_with_endmarker:
+        required_endmarker = true;
+        break;
+      case stylesv2::Type::note_paragraph:
+        break;
+      case stylesv2::Type::crossreference_wrapper:
+        required_endmarker = true;
+        break;
+      case stylesv2::Type::crossreference_standard_content:
+      case stylesv2::Type::crossreference_content:
+        break;
+      case stylesv2::Type::crossreference_content_with_endmarker:
+        required_endmarker = true;
+        break;
+      case stylesv2::Type::character:
+        required_endmarker = true;
+        embeddable_marker = true;
+        break;
+      case stylesv2::Type::page_break:
+        break;
+      case stylesv2::Type::figure:
+        required_endmarker = true;
+        break;
+      case stylesv2::Type::word_list:
+        required_endmarker = true;
+        embeddable_marker = true;
+        break;
+      case stylesv2::Type::sidebar_begin:
+      case stylesv2::Type::sidebar_end:
+      case stylesv2::Type::peripheral:
+      case stylesv2::Type::milestone:
+      case stylesv2::Type::starting_boundary:
+      case stylesv2::Type::stopping_boundary:
+      case stylesv2::Type::none:
+      default:
+        break;
     }
     if (required_endmarker) {
-      markers_requiring_endmarkers.push_back (marker);
+      markers_requiring_endmarkers.push_back (style.marker);
     }
     if (embeddable_marker) {
-      embeddable_markers.push_back (marker);
-    }
-    
-    // Look for the \toc[1-3] markers.
-    if (styleType == StyleTypeIdentifier) {
-      if (styleSubtype == IdentifierSubtypeLongTOC) long_toc1_marker = marker;
-      if (styleSubtype == IdentifierSubtypeShortTOC) short_toc2_marker = marker;
-      if (styleSubtype == IdentifierSubtypeBookAbbrev) abbrev_toc3_marker = marker;
+      embeddable_markers.push_back (style.marker);
     }
   }
 }
@@ -100,7 +147,7 @@ void Checks_Usfm::finalize ()
 {
   // Check on unclosed markers.
   if (open_matching_markers.size () > 0) {
-    add_result (translate ("Unclosed markers:") + " " + filter::strings::implode (open_matching_markers, " "), display_nothing);
+    add_result (checks::issues::text(checks::issues::issue::unclosed_markers) + ": " + filter::strings::implode (open_matching_markers, " "), display_nothing);
   }
 }
 
@@ -157,7 +204,7 @@ void Checks_Usfm::malformed_verse_number ()
     std::string dirtyVerseNumber {};
     if (!v_dirtyVerseNumber.empty ()) dirtyVerseNumber = v_dirtyVerseNumber [0];
     if (cleanVerseNumber != dirtyVerseNumber) {
-      add_result (translate ("Malformed verse number"), display_full);
+      add_result (checks::issues::text(checks::issues::issue::malformed_verse_number), display_full);
     }
   }
 }
@@ -178,7 +225,7 @@ void Checks_Usfm::new_line_in_usfm (const std::string& usfm)
     if (position == 0) position = 1;
     std::string bit = usfm.substr (position - 1, 10);
     bit = filter::strings::replace ("\n", " ", bit);
-    add_result (translate ("New line within USFM:") + " " + bit, display_nothing);
+    add_result (checks::issues::text(checks::issues::issue::new_line_within_usfm) + ": " + bit, display_nothing);
   }
 }
 
@@ -195,7 +242,7 @@ void Checks_Usfm::marker_in_stylesheet ()
   }
   if (marker.empty()) return;
   if (in_array (marker, markers_stylesheet)) return;
-  add_result (translate ("Marker not in stylesheet"), Checks_Usfm::display_current);
+  add_result (checks::issues::text(checks::issues::issue::marker_not_in_stylesheet), Checks_Usfm::display_current);
 }
 
 
@@ -212,10 +259,10 @@ void Checks_Usfm::malformed_id ()
     if (!vid.empty ()) id = vid [0];
     book_id book = database::books::get_id_from_usfm (id);
     if (book == book_id::_unknown) {
-      add_result (translate ("Unknown ID"), display_full);
+      add_result (checks::issues::text(checks::issues::issue::unknown_id), display_full);
     } else {
       if (filter::strings::unicode_string_uppercase (id) != id) {
-        add_result (translate ("ID is not in uppercase"), display_full);
+        add_result (checks::issues::text(checks::issues::issue::id_is_not_in_uppercase), display_full);
       }
     }
   }
@@ -240,7 +287,7 @@ void Checks_Usfm::forward_slash (const std::string& usfm)
     }
     const std::string marker = bit.substr (1, 100);
     if (find (markers_stylesheet.begin(), markers_stylesheet.end(), marker) != markers_stylesheet.end ()) {
-      add_result (translate ("Forward slash instead of backslash:") + " " + bit, display_nothing);
+      add_result (checks::issues::text(checks::issues::issue::forward_slash_instead_of_backslash) + ": " + bit, display_nothing);
     }
   }
 }
@@ -251,7 +298,7 @@ void Checks_Usfm::widow_back_slash ()
   std::string marker = usfm_item;
   marker = filter::strings::trim (marker);
   if (marker.length() == 1) {
-    add_result (translate ("Widow backslash"), display_current);
+    add_result (checks::issues::text(checks::issues::issue::widow_backslash), display_current);
   }
 }
 
@@ -262,14 +309,16 @@ void Checks_Usfm::matching_endmarker ()
   // Remove the initial backslash, e.g. '\add' becomes 'add'.
   marker = marker.substr (1);
   marker = filter::strings::trim (marker);
-  bool isOpener = filter::usfm::is_opening_marker (marker);
-  if (!isOpener) {
-   if (!marker.empty ()) marker = marker.substr (0, marker.length () - 1);
+  bool is_opener = filter::usfm::is_opening_marker (marker);
+  if (!is_opener) {
+    if (!marker.empty ())
+      marker.pop_back();
   }
-  if (!in_array (marker, markers_requiring_endmarkers)) return;
-  if (isOpener) {
+  if (!in_array (marker, markers_requiring_endmarkers))
+    return;
+  if (is_opener) {
     if (in_array (marker, open_matching_markers)) {
-      add_result (translate ("Repeating opening marker"), Checks_Usfm::display_current);
+      add_result (checks::issues::text(checks::issues::issue::repeating_opening_marker), Checks_Usfm::display_current);
     } else {
       open_matching_markers.push_back (marker);
     }
@@ -277,7 +326,7 @@ void Checks_Usfm::matching_endmarker ()
     if (in_array (marker, open_matching_markers)) {
       open_matching_markers = filter::strings::array_diff (open_matching_markers, {marker});
     } else {
-      add_result (translate ("Closing marker does not match opening marker") + " " + filter::strings::implode (open_matching_markers, " "), display_current);
+      add_result (checks::issues::text(checks::issues::issue::closing_marker_does_not_match_opening_marker) + " " + filter::strings::implode (open_matching_markers, " "), display_current);
     }
   }
 }
@@ -330,7 +379,7 @@ void Checks_Usfm::embedded_marker ()
   
   if (checkEmbedding) {
     if (marker.substr (0, 1) != "+") {
-      add_result (translate ("Embedded marker requires a plus sign"), display_full);
+      add_result (checks::issues::text(checks::issues::issue::embedded_marker_requires_a_plus_sign), display_full);
     }
   }
 }
@@ -352,14 +401,14 @@ void Checks_Usfm::toc (std::string usfm)
     if (chapter_number == 0) {
       // Required: \toc1
       if (!toc1_present) {
-        add_result (translate ("The book lacks the marker for the verbose book name:") + " " + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
+        add_result (checks::issues::text(checks::issues::issue::the_book_lacks_the_marker_for_the_verbose_book_name) + ": " + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
       }
       // Required: \toc2
       if (!toc2_present) {
-        add_result (translate ("The book lacks the marker for the short book name:") + " " + filter::usfm::get_opening_usfm (short_toc2_marker), display_nothing);
+        add_result (checks::issues::text(checks::issues::issue::the_book_lacks_the_marker_for_the_short_book_name) + ": " + filter::usfm::get_opening_usfm (short_toc2_marker), display_nothing);
       }
     } else {
-      const std::string msg = translate ("The following marker belongs in chapter 0:") + " ";
+      const std::string msg = checks::issues::text(checks::issues::issue::the_following_marker_belongs_in_chapter_0) + ": ";
       // Required markers.
       if (toc1_present) {
         add_result (msg + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
@@ -383,16 +432,16 @@ void Checks_Usfm::figure ()
     std::string caption, alt, src, size, loc, copy, ref;
     filter::usfm::extract_fig (usfm, caption, alt, src, size, loc, copy, ref);
     if (src.empty()) {
-      add_result (translate ("Empty figure source:") + " " + usfm, display_nothing);
+      add_result (checks::issues::text(checks::issues::issue::empty_figure_source) + ": " + usfm, display_nothing);
     } else {
       const std::string image_contents = database::bible_images::get (src);
       if (image_contents.empty()) {
-        add_result (translate ("Could not find Bible image:") + " " + src, display_nothing);
+        add_result (checks::issues::text(checks::issues::issue::could_not_find_bible_image) + ": " + src, display_nothing);
       }
     }
     const size_t pos = usfm.find("“");
     if (pos != std::string::npos) {
-      add_result (translate ("Unusual quotation mark found:") + " " + usfm, display_nothing);
+      add_result (checks::issues::text(checks::issues::issue::unusual_quotation_mark_found) + ": " + usfm, display_nothing);
     }
   }
 }
@@ -406,7 +455,7 @@ std::vector <std::pair<int, std::string>> Checks_Usfm::get_results ()
 
 void Checks_Usfm::add_result (std::string text, int modifier)
 {
-  std::string current = usfm_item;
+  const std::string current = usfm_item;
   std::string next = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
   next = next.substr (0, 20);
   switch (modifier) {
@@ -418,7 +467,7 @@ void Checks_Usfm::add_result (std::string text, int modifier)
     case display_next:
       text += ": " + next;
       break;
-    case Checks_Usfm::display_full:
+    case display_full:
       text += ": " + current + next;
       break;
     default:
@@ -471,7 +520,7 @@ void Checks_Usfm::empty_markup ()
   // Flag the following situation:
   // An opener is followed by a closer without intervening text.
   if (previous_is_opener && current_is_closer) {
-    add_result (translate ("Opening markup is followed by closing markup without intervening text:") + " " + empty_markup_previous_item + current_item, Checks_Usfm::display_nothing);
+    add_result (checks::issues::text(checks::issues::issue::opening_markup_is_followed_by_closing_markup_without_intervening_text) + ": " + empty_markup_previous_item + current_item, Checks_Usfm::display_nothing);
   }
 
   // Save the current item (markup or text) into the object for next iteration.
@@ -499,24 +548,26 @@ void Checks_Usfm::note ()
   }
 
   // If the current item is text, then do no further checks on that.
-  if (current_is_text) return;
+  if (current_is_text)
+    return;
   // From here on it is assumed that the current item is USFM, not text.
 
   // Get the plain marker, e.g. '\f ' becomes "f".
   const std::string current_marker = filter::usfm::get_marker (usfm_item);
   
   // Get this style's properties.
-  database::styles1::Item style = style_items [current_marker];
+  const stylesv2::Style* stylev2 = database::styles::get_marker_data(m_stylesheet, current_marker);
   
   // Set a flag if this USFM starts a footnote or an endnote or a crossreference.
   // Clear this flag if it ends the note or xref.
   bool note_border_marker {false};
-  if (style.type == StyleTypeFootEndNote) {
-    if (style.subtype == FootEndNoteSubtypeFootnote) note_border_marker = true;
-    if (style.subtype == FootEndNoteSubtypeEndnote) note_border_marker = true;
-  }
-  if (style.type == StyleTypeCrossreference) {
-    if (style.subtype == CrossreferenceSubtypeCrossreference) note_border_marker = true;
+  if (stylev2) {
+    if (stylev2->type == stylesv2::Type::footnote_wrapper)
+      note_border_marker = true;
+    if (stylev2->type == stylesv2::Type::endnote_wrapper)
+      note_border_marker = true;
+    if (stylev2->type == stylesv2::Type::crossreference_wrapper)
+      note_border_marker = true;
   }
   if (note_border_marker) {
     if (current_is_opener) within_note = true;
@@ -525,7 +576,8 @@ void Checks_Usfm::note ()
 
   // If the current location is not within a footnote / endnote / cross reference,
   // then there is nothing to check for.
-  if (!within_note) return;
+  if (!within_note)
+    return;
 
   // Get the next item, that is the item following the current item.
   const std::string next_item = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
@@ -561,7 +613,7 @@ void Checks_Usfm::note ()
 
   // It has not passed the text for a correctly formatted note.
   // So add a message.
-  add_result (translate ("This sequence in the note does not look right:") + " " + usfm_item + next_item, display_nothing);
+  add_result (checks::issues::text(checks::issues::issue::this_sequence_in_the_note_does_not_look_right) + ": " + usfm_item + next_item, display_nothing);
 }
 
 
