@@ -47,8 +47,8 @@ private:
   static constexpr int display_full {3};
   
   // Stylesheet.
+  std::string m_stylesheet {};
   std::vector <std::string> markers_stylesheet {};
-  std::map <std::string, database::styles1::Item> style_items {};
   
   // Matching markers.
   std::vector <std::string> markers_requiring_endmarkers {};
