@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -47,8 +47,6 @@ public:
   void logHistory (const std::string& bible, int year, int month, int day, int tasks, int complete);
   std::vector <Database_Sprint_Item> getHistory (const std::string& bible, int year, int month);
   void clearHistory (const std::string& bible, int year, int month);
-private:
-  sqlite3 * connect ();
 };
 
 #endif
