@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,6 +26,4 @@ class Database_Strong
 public:
   std::string definition (std::string strong);
   std::vector <std::string> strong (std::string lemma);
-private:
-  sqlite3 * connect ();
 };
