@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/string.h>
 #include <database/logic.h>
-using namespace std;
 
 
 // Database resilience: 
@@ -29,39 +28,39 @@ using namespace std;
 // That is resilient enough.
 
 
-string Database_UsfmResources::mainFolder ()
+std::string Database_UsfmResources::mainFolder ()
 {
   return filter_url_create_root_path ({database_logic_databases (), "usfmresources"});
 }
 
 
-string Database_UsfmResources::resourceFolder (const string& name)
+std::string Database_UsfmResources::resourceFolder (const std::string& name)
 {
   return filter_url_create_path ({mainFolder (), name});
 }
 
 
-string Database_UsfmResources::bookFolder (const string& name, int book)
+std::string Database_UsfmResources::bookFolder (const std::string& name, int book)
 {
-  return filter_url_create_path ({resourceFolder (name), filter::strings::convert_to_string (book)});
+  return filter_url_create_path ({resourceFolder (name), std::to_string (book)});
 }
 
 
-string Database_UsfmResources::chapterFile (const string& name, int book, int chapter)
+std::string Database_UsfmResources::chapterFile (const std::string& name, int book, int chapter)
 {
-  return filter_url_create_path ({bookFolder (name, book), filter::strings::convert_to_string (chapter)});
+  return filter_url_create_path ({bookFolder (name, book), std::to_string (chapter)});
 }
 
 
-vector <string> Database_UsfmResources::getResources ()
+std::vector <std::string> Database_UsfmResources::getResources ()
 {
   return filter_url_scandir (mainFolder ());
 }
 
 
-void Database_UsfmResources::deleteResource (const string& name)
+void Database_UsfmResources::deleteResource (const std::string& name)
 {
-  string path = resourceFolder (name);
+  std::string path = resourceFolder (name);
   // If a folder: Delete it.
   filter_url_rmdir (path);
   // If a file: Delete it.
@@ -69,9 +68,9 @@ void Database_UsfmResources::deleteResource (const string& name)
 }
 
 
-void Database_UsfmResources::deleteBook (const string& name, int book)
+void Database_UsfmResources::deleteBook (const std::string& name, int book)
 {
-  string path = bookFolder (name, book);
+  std::string path = bookFolder (name, book);
   // If a folder: Delete it.
   filter_url_rmdir (path);
   // If a file: Delete it.
@@ -79,51 +78,51 @@ void Database_UsfmResources::deleteBook (const string& name, int book)
 }
 
 
-void Database_UsfmResources::deleteChapter (const string& name, int book, int chapter)
+void Database_UsfmResources::deleteChapter (const std::string& name, int book, int chapter)
 {
   filter_url_unlink (chapterFile (name, book, chapter));
 }
 
 
-void Database_UsfmResources::storeChapter (const string& name, int book, int chapter, const string& usfm)
+void Database_UsfmResources::storeChapter (const std::string& name, int book, int chapter, const std::string& usfm)
 {
-  string file = chapterFile (name, book, chapter);
-  string folder = filter_url_dirname (file);
+  std::string file = chapterFile (name, book, chapter);
+  std::string folder = filter_url_dirname (file);
   if (!file_or_dir_exists (folder)) filter_url_mkdir (folder);
   filter_url_file_put_contents (file, usfm);
 }
 
 
-vector <int> Database_UsfmResources::getBooks (const string& name)
+std::vector <int> Database_UsfmResources::getBooks (const std::string& name)
 {
-  vector <int> books;
-  vector <string> files = filter_url_scandir (resourceFolder (name));
+  std::vector <int> books;
+  std::vector <std::string> files = filter_url_scandir (resourceFolder (name));
   for (auto & book : files) books.push_back (filter::strings::convert_to_int (book));
   sort (books.begin (), books.end());
   return books;
 }
 
 
-vector <int> Database_UsfmResources::getChapters (const string& name, int book)
+std::vector <int> Database_UsfmResources::getChapters (const std::string& name, int book)
 {
-  vector <int> chapters;
-  vector <string> folders = filter_url_scandir (bookFolder (name, book));
+  std::vector <int> chapters;
+  std::vector <std::string> folders = filter_url_scandir (bookFolder (name, book));
   for (auto & chapter : folders) chapters.push_back (filter::strings::convert_to_int (chapter));
   sort (chapters.begin(), chapters.end());
   return chapters;
 }
 
 
-string Database_UsfmResources::getUsfm (const string& name, int book, int chapter)
+std::string Database_UsfmResources::getUsfm (const std::string& name, int book, int chapter)
 {
-  string file = chapterFile (name, book, chapter);
-  string usfm = filter_url_file_get_contents (file);
+  std::string file = chapterFile (name, book, chapter);
+  std::string usfm = filter_url_file_get_contents (file);
   return usfm;
 }
 
 
-int Database_UsfmResources::getSize (const string& name, int book, int chapter)
+int Database_UsfmResources::getSize (const std::string& name, int book, int chapter)
 {
-  string file = chapterFile (name, book, chapter);
+  std::string file = chapterFile (name, book, chapter);
   return filter_url_filesize (file);
 }
