@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2024 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,14 +24,6 @@ var chapterEditorUniqueID = Math.floor (Math.random() * 100000000);
 
 $ (document).ready (function ()
 {
-  // Listens for bibleselect option tags value change to update the loaded Bible.
-  var bibleSelectionElement = document.querySelector ("#bibleselect");
-  bibleSelectionElement.addEventListener ('change', () => {
-    var value = bibleSelectionElement.value;
-    $.post ("index", { bibleselect: bibleSelectionElement.value })
-      .done (function() { window.location.reload () });
-  });
-
   // Reposition the editor's menu so it never scrolls out of view.
   var bar = $ ("#editorheader").remove ();
   $ ("#workspacemenu").append (bar);
@@ -141,7 +133,7 @@ var editorNavigationVerse;
 
 function navigationNewPassage ()
 {
-  if (typeof navigationBook != 'undefined') {
+  if (is_outside_workspace()) {
     editorNavigationBook = navigationBook;
     editorNavigationChapter = navigationChapter;
     editorNavigationVerse = navigationVerse;
@@ -585,6 +577,8 @@ function editorActiveStylesFeedback ()
   var character = "";
   if (format.character) character = format.character;
   if (character.search ("note") >= 0) character = "";
+  var pos = character.indexOf ("wla");
+  if (pos >= 0) character = character.substring(0, pos);
   character = character.split ("0").join (" ");
   var styles = paragraph + " " + character;
   styles = styles.replace ("versebeam", "");
@@ -1112,7 +1106,7 @@ function editorLog (msg)
 
 function editorSwipeLeft (event)
 {
-  if (typeof navigateNextChapter != 'undefined') {
+  if (is_outside_workspace()) {
     navigateNextChapter (event);
   } else if (parent.window.navigateNextChapter != 'undefined') {
     parent.window.navigateNextChapter (event);
@@ -1122,7 +1116,7 @@ function editorSwipeLeft (event)
 
 function editorSwipeRight (event)
 {
-  if (typeof navigatePreviousChapter != 'undefined') {
+  if (is_outside_workspace()) {
     navigatePreviousChapter (event);
   } else if (parent.window.navigatePreviousChapter != 'undefined') {
     parent.window.navigatePreviousChapter (event);
