@@ -37,7 +37,7 @@
 #include <edit/logic.h>
 #include <access/bible.h>
 #include <bb/logic.h>
-#include <quill/logic.h>
+#include <filter/quill.h>
 #include <rss/logic.h>
 #include <sendreceive/logic.h>
 
@@ -50,7 +50,7 @@ std::string edit_save_url ()
 
 bool edit_save_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+  if (roles::access_control (webserver_request, roles::translator))
     return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return read;
@@ -59,17 +59,17 @@ bool edit_save_acl (Webserver_Request& webserver_request)
 
 std::string edit_save (Webserver_Request& webserver_request)
 {
-  bool post_complete = (webserver_request.post.count ("bible") && webserver_request.post.count ("book") && webserver_request.post.count ("chapter") && webserver_request.post.count ("html") && webserver_request.post.count ("checksum"));
+  bool post_complete = (webserver_request.post_count("bible") && webserver_request.post_count("book") && webserver_request.post_count("chapter") && webserver_request.post_count("html") && webserver_request.post_count("checksum"));
   if (!post_complete) {
     return translate("Insufficient information");
   }
 
-  const std::string bible = webserver_request.post["bible"];
-  const int book = filter::strings::convert_to_int (webserver_request.post["book"]);
-  const int chapter = filter::strings::convert_to_int (webserver_request.post["chapter"]);
-  std::string html = webserver_request.post["html"];
-  const std::string checksum = webserver_request.post["checksum"];
-  const std::string unique_id = webserver_request.post ["id"];
+  const std::string bible = webserver_request.post_get("bible");
+  const int book = filter::strings::convert_to_int (webserver_request.post_get("book"));
+  const int chapter = filter::strings::convert_to_int (webserver_request.post_get("chapter"));
+  std::string html = webserver_request.post_get("html");
+  const std::string checksum = webserver_request.post_get("checksum");
+  const std::string unique_id = webserver_request.post_get("id");
 
   if (checksum_logic::get (html) != checksum) {
     webserver_request.response_code = 409;
