@@ -25,26 +25,39 @@
 #include <styles/logic.h>
 #include <database/logs.h>
 #include <pugixml/utils.h>
-#include <quill/logic.h>
+#include <filter/quill.h>
 
 
-// This function returns a pair of:
+// This function returns a struct of:
 // 1. Normal classes, like "add", "nd", and so on.
-// 2. A string with the word-level attributes class, like "wla2" for example
-static std::pair<std::vector<std::string>, std::string>const get_standard_classes_and_wla_class (const std::string& class_name)
+// 2. A string with the word-level attributes class, like "wla2" for example.
+// 3. A string with the milestone attributes class, like "mls2" for example.
+struct std_wla_mls {
+  std::vector<std::string> standard_classes;
+  std::string word_level_attributes_class;
+  std::string milestone_attributes_class;
+};
+static std_wla_mls get_standard_classes_and_wla_or_mls_class (const std::string& class_name)
 {
+  std_wla_mls std_wla_mls;
   constexpr char separator = '0';
   std::vector <std::string> classes = filter::strings::explode (class_name, separator);
   std::string wla{};
   for (auto iter = classes.cbegin(); iter != classes.cend(); iter++) {
-    if (iter->find(quill_word_level_attribute_class_prefix) == 0) {
-      wla = *iter;
+    if (iter->find(quill::word_level_attribute_class_prefix) == 0) {
+      std_wla_mls.word_level_attributes_class = *iter;
+      classes.erase(iter);
+      break;
+    }
+    if (iter->find(quill::milestone_attribute_class_prefix) == 0) {
+      std_wla_mls.milestone_attributes_class = *iter;
       classes.erase(iter);
       break;
     }
   }
-  return {classes, wla};
-};
+  std_wla_mls.standard_classes = std::move(classes);
+  return std_wla_mls;
+}
 
 
 void Editor_Html2Usfm::load (std::string html)
@@ -58,10 +71,10 @@ void Editor_Html2Usfm::load (std::string html)
 
   const std::string xml = "<body>" + std::move(html) + "</body>";
   // Parse document such that all whitespace is put in the DOM tree.
-  // See http://pugixml.org/docs/manual.html for more information.
+  // See https://pugixml.org/docs/manual.html for more information.
   // It is not enough to only parse with parse_ws_pcdata_single, it really needs parse_ws_pcdata.
   // This is significant for, for example, the space after verse numbers, among other cases.
-  pugi::xml_parse_result result = document.load_string (xml.c_str(), pugi::parse_ws_pcdata);
+  pugi::xml_parse_result result = m_document.load_string (xml.c_str(), pugi::parse_ws_pcdata);
   // Log parsing errors.
   pugixml_utils_error_logger (&result, xml);
 }
@@ -69,42 +82,54 @@ void Editor_Html2Usfm::load (std::string html)
 
 void Editor_Html2Usfm::stylesheet (const std::string& stylesheet)
 {
-  styles.clear ();
-  note_openers.clear ();
-  character_styles.clear ();
-  const std::vector <std::string> markers = database::styles1::get_markers (stylesheet);
-  // Load the style information into the object.
-  for (const std::string& marker : markers) {
-    database::styles1::Item style = database::styles1::get_marker_data (stylesheet, marker);
-    styles [marker] = style;
+  m_note_openers.clear();
+  m_suppress_end_markers.clear();
+  m_force_end_markers.clear();
+  m_character_styles.clear();
+  const std::list<stylesv2::Style> styles = database::styles::get_styles (stylesheet);
+  for (const auto& style : styles) {
+    // Paragraph styles normally don't have a closing USFM marker.
+    // But there's exceptions to this rule.
+    // Gather the markers that need a closing USFM marker.
+    if (stylesv2::get_parameter<bool>(&style, stylesv2::Property::has_endmarker))
+      m_force_end_markers.insert(style.marker);
     // Get markers that should not have endmarkers.
-    bool suppress = false;
-    const int type = style.type;
-    const int subtype = style.subtype;
-    if (type == StyleTypeVerseNumber)
-      suppress = true;
-    if (type == StyleTypeFootEndNote) {
-      suppress = true;
-      if (subtype == FootEndNoteSubtypeFootnote)
-        note_openers.insert (marker);
-      if (subtype == FootEndNoteSubtypeEndnote)
-        note_openers.insert (marker);
-      if (subtype == FootEndNoteSubtypeContentWithEndmarker)
-        suppress = false;
-      if (subtype == FootEndNoteSubtypeParagraph)
-        suppress = false;
+    // Gather the note openers.
+    bool suppress_endmarker = false;
+    if (style.type == stylesv2::Type::verse)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::table_row)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::table_heading)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::table_cell)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::footnote_wrapper) {
+      suppress_endmarker = true;
+      m_note_openers.insert (style.marker);
     }
-    if (type == StyleTypeCrossreference) {
-      suppress = true;
-      if (subtype == CrossreferenceSubtypeCrossreference)
-        note_openers.insert (marker);
-      if (subtype == CrossreferenceSubtypeContentWithEndmarker)
-        suppress = false;
+    if (style.type == stylesv2::Type::endnote_wrapper) {
+      suppress_endmarker = true;
+      m_note_openers.insert (style.marker);
     }
-    if (type == StyleTypeTableElement)
-      suppress = true;
-    if (suppress)
-      suppress_end_markers.insert (marker);
+    if (style.type == stylesv2::Type::note_standard_content)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::note_content)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::note_paragraph)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::crossreference_wrapper) {
+      suppress_endmarker = true;
+      m_note_openers.insert (style.marker);
+    }
+    if (style.type == stylesv2::Type::crossreference_standard_content)
+      suppress_endmarker = true;
+    if (style.type == stylesv2::Type::crossreference_content)
+      suppress_endmarker = true;
+    if (suppress_endmarker)
+      m_suppress_end_markers.insert (style.marker);
+    if (style.type == stylesv2::Type::milestone)
+      m_milestone_markers.insert (style.marker);
   }
 }
 
@@ -120,13 +145,13 @@ void Editor_Html2Usfm::run ()
 void Editor_Html2Usfm::main_process ()
 {
   // Iterate over the children to retrieve the "p" elements, then process them.
-  const pugi::xml_node body = document.first_child ();
+  const pugi::xml_node body = m_document.first_child ();
   for (pugi::xml_node& node : body.children()) {
     // Do not process the notes <p> and beyond
     // because it is at the end of the text body,
     // and note-related data has already been extracted from it.
     const std::string classs = update_quill_class (node.attribute ("class").value ());
-    if (classs == quill_notes_class) {
+    if (classs == quill::notes_class) {
       break;
     }
     // Process the node.
@@ -138,7 +163,7 @@ void Editor_Html2Usfm::main_process ()
 std::string Editor_Html2Usfm::get ()
 {
   // Generate the USFM as one string.
-  const std::string usfm = filter::strings::implode (output, "\n");
+  const std::string usfm = filter::strings::implode (m_output, "\n");
   return clean_usfm (usfm);
 }
 
@@ -151,11 +176,11 @@ void Editor_Html2Usfm::process_node(pugi::xml_node& node)
       const std::string classs = node.attribute("class").value();
       // Skip a node with class "ql-cursor" because that is an internal Quill node.
       // The user didn't insert it.
-      if (classs == quill_caret_class)
+      if (classs == quill::caret_class)
         break;
       // Skip a node that is for the word-level attributes since it is just there for visual appearance.
       // The user didn't insert it.
-      if (classs.find(quill_word_level_attributes_class) != std::string::npos)
+      if (classs.find(quill::word_level_attributes_class) != std::string::npos)
         break;
       // Process this node.
       open_element_node (node);
@@ -169,7 +194,7 @@ void Editor_Html2Usfm::process_node(pugi::xml_node& node)
     {
       // Add the text to the current USFM line.
       m_last_added_text_fragment = node.text ().get ();
-      current_line.append(m_last_added_text_fragment);
+      m_current_line.append(m_last_added_text_fragment);
       break;
     }
     case pugi::node_null:
@@ -202,10 +227,10 @@ void Editor_Html2Usfm::open_element_node (pugi::xml_node& node)
       class_name = "p";
     if (class_name == "mono") {
       // Class 'mono': The editor has the full USFM in the text.
-      mono = true;
+      m_mono = true;
     } else {
       // Start the USFM line with a marker with the class name.
-      current_line.append(filter::usfm::get_opening_usfm (class_name));
+      m_current_line.append(filter::usfm::get_opening_usfm (class_name));
     }
   }
   
@@ -219,7 +244,7 @@ void Editor_Html2Usfm::open_element_node (pugi::xml_node& node)
     else if (class_name.empty ()) {
       // Normal text is wrapped in elements without a class attribute.
     }
-    else if (class_name.substr (0, quill_note_caller_class.size()) == quill_note_caller_class) {
+    else if (class_name.substr (0, quill::note_caller_class.size()) == quill::note_caller_class) {
       // Note in Quill-based editor.
       process_note_citation (node);
     }
@@ -242,8 +267,9 @@ void Editor_Html2Usfm::close_element_node (const pugi::xml_node& node)
   const std::string tag_name = node.name ();
   // Get the class names of this node.
   // Get the word-level attributes class name / identifier.
+  // Get the milestone attributes class name / identifier.
   std::string class_name = update_quill_class (node.attribute ("class").value ());
-  auto [classes, wla_class] = get_standard_classes_and_wla_class (class_name);
+  auto std_wla_mls = get_standard_classes_and_wla_or_mls_class (class_name);
 
   if (tag_name == "p")
   {
@@ -252,55 +278,114 @@ void Editor_Html2Usfm::close_element_node (const pugi::xml_node& node)
     if (class_name.empty())
       class_name = "p";
     
-    if (note_openers.find (class_name) != note_openers.end()) {
+    if (m_note_openers.find (class_name) != m_note_openers.cend()) {
       // Deal with note closers.
-      current_line.append(filter::usfm::get_closing_usfm (class_name));
+      m_current_line.append(filter::usfm::get_closing_usfm (class_name));
     } else {
+      // If this style should add an endmarker, handle that here.
+      if (m_force_end_markers.find(class_name) != m_force_end_markers.cend()) {
+        m_current_line.append(filter::usfm::get_closing_usfm (class_name));
+      }
       // Normally a p element closes the USFM line.
       flush_line ();
-      mono = false;
+      m_mono = false;
       // Clear active character styles.
-      character_styles.clear();
+      m_character_styles.clear();
     }
   }
   
   if (tag_name == "span")
   {
     // Do nothing for monospace elements, because the USFM would be the text nodes only.
-    if (mono)
+    if (m_mono)
       return;
     // Do nothing without a class.
     if (class_name.empty())
       return;
     // Do nothing with a note caller.
-    if (class_name.substr (0, quill_note_caller_class.size()) == quill_note_caller_class)
+    if (class_name.substr (0, quill::note_caller_class.size()) == quill::note_caller_class)
       return;
-    // Do nothing if no endmarkers are supposed to be produced.
-    // There's two exceptions:
-    // 1. If a word-level attributes ID was found: This needs an endmarker.
-    // 2. If the last added text fragment contains the vertical bar, as that indicates word-level attributes.
-    if (suppress_end_markers.find (class_name) != suppress_end_markers.end()) {
-      if ((wla_class.empty()) && (m_last_added_text_fragment.find("|") == std::string::npos))
+
+    // Check for and get and handle word-level attributes.
+    if (!std_wla_mls.word_level_attributes_class.empty()) {
+      if (!m_word_level_attributes[std_wla_mls.word_level_attributes_class].empty()) {
+        // The vertical bar separates the canonical word from the attribute(s) following it.
+        m_current_line.append("|");
+        m_current_line.append(std::move(m_word_level_attributes[std_wla_mls.word_level_attributes_class]));
+      }
+      // Clean up.
+      m_word_level_attributes.erase(std_wla_mls.word_level_attributes_class);
+    }
+
+    // Function for detecting whether closing a milestone class.
+    const auto is_milestone = [this, &std_wla_mls, &class_name]() {
+      if (!std_wla_mls.milestone_attributes_class.empty())
+        return true;
+      if (m_milestone_markers.find (class_name) != m_milestone_markers.end())
+        return true;
+      return false;
+    };
+    
+    // If this is a milestone, then it means that the current line contains the milestone emoji.
+    // This emoji is put in the editor for visual appearance only, but should not be part of the USFM generated.
+    // Remove it here.
+    if (is_milestone())
+      m_current_line = filter::strings::replace (quill::milestone_emoji, std::string(), std::move(m_current_line));
+
+    // Check for and get and handle milestone attributes.
+    if (is_milestone()) {
+      if (!m_milestone_attributes[std_wla_mls.milestone_attributes_class].empty()) {
+        // The vertical bar separates the opening marker from the attribute(s) following it.
+        m_current_line.append("|");
+        m_current_line.append(m_milestone_attributes[std_wla_mls.milestone_attributes_class]);
+      }
+      // Clean up.
+      m_milestone_attributes.erase(std_wla_mls.milestone_attributes_class);
+    }
+
+    // Do nothing more if no endmarkers are supposed to be produced.
+    // There's an exception in the case of linking attributes.
+    if (m_suppress_end_markers.find (class_name) != m_suppress_end_markers.end()) {
+      // Linking attributes are used in this: \xt 1|GEN 2:1\xt*
+      // It means the signature is that the last added text fragment contains the vertical bar,
+      // but not right at the first position.
+      // This distinguishes it from the vertical bar that is used when inserting a note in the Bible editor.
+      // See https://github.com/bibledit/cloud/issues/1030
+      const auto linking_attribute = [this] () {
+        const std::size_t pos = m_last_added_text_fragment.find("|");
+        if (pos == std::string::npos)
+          return false;
+        if (pos != 0)
+          return true;
+        return false;
+      };
+      if (!linking_attribute())
         return;
     }
-    // Check for and get and handle word-level attributes.
-    if (!wla_class.empty()) {
-      const std::string contents = m_word_level_attributes[wla_class];
-      m_word_level_attributes.erase(wla_class);
-      if (!contents.empty()) {
-        // The vertical bar separates the canonical word from the attribute(s) following it.
-        current_line.append("|");
-        current_line.append(contents);
-      }
-    }
+    
     // Add closing USFM, optionally closing embedded tags in reverse order.
-    character_styles = filter::strings::array_diff (character_styles, classes);
-    reverse (classes.begin(), classes.end());
-    for (unsigned int offset = 0; offset < classes.size(); offset++) {
-      bool embedded = (classes.size () > 1) && (offset == 0);
-      if (!character_styles.empty ()) embedded = true;
-      current_line.append (filter::usfm::get_closing_usfm (classes [offset], embedded));
-      last_note_style.clear();
+    m_character_styles = filter::strings::array_diff (m_character_styles, std_wla_mls.standard_classes);
+    reverse (std_wla_mls.standard_classes.begin(), std_wla_mls.standard_classes.end());
+    for (unsigned int offset = 0; offset < std_wla_mls.standard_classes.size(); offset++) {
+      bool embedded = (std_wla_mls.standard_classes.size () > 1) && (offset == 0);
+      if (!m_character_styles.empty ())
+        embedded = true;
+      if (is_milestone()) {
+        // Adding a milestone endmarker: \*
+        // If the last character of the current line is a space,
+        // it is assumed that this is the space from the milestone opening marker.
+        // If the opener is followed by the closer, without attributes between them,
+        // then in USFM it is customary to remove that last space.
+        // The resulting fragment then looks like e.g. this: \qt-e\*
+        if (!m_current_line.empty())
+          if (m_current_line.back() == ' ')
+            m_current_line.pop_back();
+        m_current_line.append (filter::usfm::get_closing_usfm (std::string(), false));
+      }
+      else
+        // Normal endmarker: \marker*
+        m_current_line.append (filter::usfm::get_closing_usfm (std_wla_mls.standard_classes [offset], embedded));
+      m_last_note_style.clear();
     }
   }
   
@@ -317,32 +402,36 @@ void Editor_Html2Usfm::open_inline (const std::string& class_name)
   // The <span class="add">
   //   <span class="nd">Lord God</span>
   // is calling</span> you</span><span>.</span>
-  const auto [classes, wla] = get_standard_classes_and_wla_class(class_name);
-  for (unsigned int offset = 0; offset < classes.size(); offset++) {
-    const bool embedded = (character_styles.size () + offset) > 0;
-    const std::string marker = classes[offset];
+  const auto std_wla_mls = get_standard_classes_and_wla_or_mls_class(class_name);
+  for (unsigned int offset = 0; offset < std_wla_mls.standard_classes.size(); offset++) {
+    const bool embedded = (m_character_styles.size () + offset) > 0;
+    std::string marker = std_wla_mls.standard_classes.at(offset);
+    // Milestones have an underscore due to requirement of Quill editor: Change to hyphen.
+    if (!std_wla_mls.milestone_attributes_class.empty())
+      marker = quill::underscore_to_hyphen (std::move(marker));
     bool add_opener = true;
-    if (processing_note) {
+    if (m_processing_note) {
       // If the style within the note has already been opened before,
       // do not open the same style again.
       // https://github.com/bibledit/cloud/issues/353
-      if (marker == last_note_style) add_opener = false;
-      last_note_style = marker;
+      if (marker == m_last_note_style)
+        add_opener = false;
+      m_last_note_style = marker;
     } else {
-      last_note_style.clear ();
+      m_last_note_style.clear ();
     }
     if (add_opener) {
-      current_line.append (filter::usfm::get_opening_usfm (marker, embedded));
+      m_current_line.append (filter::usfm::get_opening_usfm (marker, embedded));
     }
   }
   // Store active character styles in some cases.
   bool store = true;
-  if (suppress_end_markers.find (class_name) != suppress_end_markers.end ())
+  if (m_suppress_end_markers.find (class_name) != m_suppress_end_markers.end ())
     store = false;
-  if (processing_note)
+  if (m_processing_note)
     store = false;
   if (store) {
-    character_styles.insert (character_styles.end(), classes.begin(), classes.end());
+    m_character_styles.insert (m_character_styles.end(), std_wla_mls.standard_classes.begin(), std_wla_mls.standard_classes.end());
   }
 }
 
@@ -366,11 +455,11 @@ void Editor_Html2Usfm::process_note_citation (pugi::xml_node& node)
   // <p class="b-f"><span class="i-notebody1">1</span> + <span class="i-ft">notetext</span></p>
   // Retrieve the <a> element from it.
   // This was initially done through an XPath expression:
-  // http://www.grinninglizard.com/tinyxml2docs/index.html
+  // https://www.grinninglizard.com/tinyxml2docs/index.html
   // But XPath crashed on Android with libxml2.
   // Therefore now it iterates over all the nodes to find the required element.
   // After moving to pugixml, the XPath expression could have been used again, but this was not done.
-  pugi::xml_node note_p_element = get_note_pointer (document.first_child (), id);
+  pugi::xml_node note_p_element = get_note_pointer (m_document.first_child (), id);
   if (note_p_element) {
 
     // It now has the <p>.
@@ -392,16 +481,16 @@ void Editor_Html2Usfm::process_note_citation (pugi::xml_node& node)
     }
 
     // Preserve active character styles in the main text, and reset them for the note.
-    std::vector <std::string> preserved_character_styles = std::move(character_styles);
-    character_styles.clear();
+    std::vector <std::string> preserved_character_styles = std::move(m_character_styles);
+    m_character_styles.clear();
     
     // Process this 'p' element.
-    processing_note = true;
+    m_processing_note = true;
     process_node(note_p_element);
-    processing_note = false;
+    m_processing_note = false;
     
     // Restore the active character styles for the main text.
-    character_styles = std::move(preserved_character_styles);
+    m_character_styles = std::move(preserved_character_styles);
     
     // Remove this element so it can't be processed again.
     pugi::xml_node parent = note_p_element.parent ();
@@ -416,7 +505,7 @@ void Editor_Html2Usfm::process_note_citation (pugi::xml_node& node)
 std::string Editor_Html2Usfm::clean_usfm (std::string usfm)
 {
   // Replace a double space after a note opener.
-  for (const std::string& noteOpener : note_openers) {
+  for (const std::string& noteOpener : m_note_openers) {
     const std::string opener = filter::usfm::get_opening_usfm (noteOpener);
     usfm = filter::strings::replace (opener + " ", opener, usfm);
   }
@@ -431,45 +520,71 @@ std::string Editor_Html2Usfm::clean_usfm (std::string usfm)
 
 void Editor_Html2Usfm::pre_process ()
 {
-  output.clear ();
-  current_line.clear ();
-  mono = false;
+  m_output.clear ();
+  m_current_line.clear ();
+  m_mono = false;
   m_word_level_attributes.clear();
+  m_milestone_attributes.clear();
   
   // Remove the node for word-level attributes that was there only for visual appearance in the editors.
-  // Store the word-level attributes themsselves in a container ready for use.
-  // And remove those nodes too from the XML tree.
-  std::vector<pugi::xml_node> delete_nodes{};
-  pugi::xml_node body = document.first_child ();
-  for (pugi::xml_node& node : body.children()) {
-    const std::string classs = update_quill_class (node.attribute ("class").value ());
-    if (classs == quill_word_level_attributes_class) {
-      delete_nodes.push_back(node);
+  // Store the word-level attributes themselves in a container ready for use.
+  // And remove those nodes from the XML tree.
+  {
+    std::vector<pugi::xml_node> delete_nodes{};
+    pugi::xml_node body = m_document.first_child ();
+    for (pugi::xml_node& node : body.children()) {
+      const std::string classs = update_quill_class (node.attribute ("class").value ());
+      if (classs == quill::word_level_attributes_class) {
+        delete_nodes.push_back(node);
+      }
+      // The classs could be "wla1", and the prefix is "wla", so check on the match.
+      if (classs.find(quill::word_level_attribute_class_prefix) == 0) {
+        delete_nodes.push_back(node);
+        const std::string text = node.text().get();
+        m_word_level_attributes.insert({classs, text});
+      }
     }
-    // The classs could be "wla1", and the prefix is "wla", so check on the match.
-    if (classs.find(quill_word_level_attribute_class_prefix) == 0) {
-      delete_nodes.push_back(node);
-      const std::string text = node.text().get();
-      m_word_level_attributes.insert({classs, text});
+    for (auto& node : delete_nodes) {
+      body.remove_child(node);
     }
   }
-  for (auto& node : delete_nodes) {
-    body.remove_child(node);
+
+  // Remove the node for milestone attributes that was there only for visual appearance in the editors.
+  // Store the milestone attributes themselves in a container ready for use.
+  // And remove those nodes from the XML tree.
+  {
+    std::vector<pugi::xml_node> delete_nodes{};
+    pugi::xml_node body = m_document.first_child ();
+    for (pugi::xml_node& node : body.children()) {
+      const std::string classs = update_quill_class (node.attribute ("class").value ());
+      if (classs == quill::milestone_attributes_class) {
+        delete_nodes.push_back(node);
+      }
+      // The classs could be "mls1", and the prefix is "mls", so check on the match.
+      if (classs.find(quill::milestone_attribute_class_prefix) == 0) {
+        delete_nodes.push_back(node);
+        const std::string text = node.text().get();
+        m_milestone_attributes.insert({classs, text});
+      }
+    }
+    for (auto& node : delete_nodes) {
+      body.remove_child(node);
+    }
   }
 }
 
 
 void Editor_Html2Usfm::flush_line ()
 {
-  if (!current_line.empty ()) {
+  if (!m_current_line.empty ()) {
     // Trim so that '\p ' becomes '\p', for example.
-    current_line = filter::strings::trim (std::move(current_line));
+    m_current_line = filter::strings::trim (std::move(m_current_line));
     // No longer doing the above
     // because it would remove a space intentionally added to the end of a line.
     // Instead it now only does a left trim instead of the full trim.
     // current_line = filter::strings::ltrim (current_line);
-    output.push_back (std::move(current_line));
-    current_line.clear ();
+    m_output.push_back (std::move(m_current_line));
+    m_current_line.clear ();
   }
 }
 
@@ -479,10 +594,13 @@ void Editor_Html2Usfm::post_process ()
   // Flush any last USFM line being built.
   flush_line ();
   
-  // Log any word-level attributes that have not been integrated into the USFM.
+  // Log any word-level and milestone attributes that have not been integrated into the USFM.
   for (const auto& element : m_word_level_attributes) {
     Database_Logs::log ("Discarding unprocessed word-level attribute with key: " + element.first + " and value: " + element.second);
   }
+  for (const auto& element : m_milestone_attributes) {
+    Database_Logs::log ("Discarding unprocessed milestone attribute with key: " + element.first + " and value: " + element.second);
+  }
 }
 
 
@@ -557,8 +675,9 @@ pugi::xml_node Editor_Html2Usfm::get_note_pointer (const pugi::xml_node& body, c
 
 std::string Editor_Html2Usfm::update_quill_class (std::string classname)
 {
-  classname = filter::strings::replace (quill_class_prefix_block, std::string(), classname);
-  classname = filter::strings::replace (quill_class_prefix_inline, std::string(), classname);
+  classname = filter::strings::replace (quill::class_prefix_block, std::string(), std::move(classname));
+  classname = filter::strings::replace (quill::class_prefix_inline, std::string(), std::move(classname));
+  classname = quill::underscore_to_hyphen (std::move(classname));
   return classname;
 }
 
@@ -573,7 +692,7 @@ std::string editor_export_verse_quill (const std::string& stylesheet, std::strin
   const std::string one_verse_style = "oneversestyle";
   const size_t pos = html.find ("<p>");
   if (pos == 0) {
-    html.insert (2, R"( class=")" + std::string(quill_class_prefix_block) + one_verse_style + R"(")");
+    html.insert (2, R"( class=")" + std::string(quill::class_prefix_block) + one_verse_style + R"(")");
   }
 
   // Convert html to USFM.
