@@ -36,7 +36,7 @@ std::string editor_id_url ()
 
 bool editor_id_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+  if (roles::access_control (webserver_request, roles::translator))
     return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return read;
@@ -46,7 +46,7 @@ bool editor_id_acl (Webserver_Request& webserver_request)
 std::string editor_id (Webserver_Request& webserver_request)
 {
   // Update the timestamp indicating that the Bible editor is alive.
-  webserver_request.database_config_user()->setLiveBibleEditor (filter::date::seconds_since_epoch ());
+  webserver_request.database_config_user()->set_live_bible_editor (filter::date::seconds_since_epoch ());
 
   
   std::string bible = webserver_request.query ["bible"];
