@@ -26,10 +26,10 @@ class Webserver_Request;
 class Editor_Styles
 {
 public:
-  static std::string getRecentlyUsed (Webserver_Request& webserver_request);
-  static std::string getAll (Webserver_Request& webserver_request);
-  static void recordUsage (Webserver_Request& webserver_request, const std::string& style);
-  static std::string getAction (Webserver_Request& webserver_request, const std::string& style);
+  static std::string get_recently_used (Webserver_Request& webserver_request);
+  static std::string get_all (Webserver_Request& webserver_request);
+  static void record_usage (Webserver_Request& webserver_request, const std::string& style);
+  static std::string get_action (Webserver_Request& webserver_request, const std::string& style);
 private:
   static std::string unknown ();
   static std::string paragraph ();
