@@ -22,18 +22,10 @@ var usfmEditorUniqueID = Math.floor (Math.random() * 100000000);
 
 $(document).ready (function ()
 {
-  // Listens for bibleselect option tags value change to update the loaded Bible.
-  var bibleSelectionElement = document.querySelector ("#bibleselect");
-  bibleSelectionElement.addEventListener ('change', () => {
-    $.post ("index", { bibleselect: bibleSelectionElement.value })
-      .done (function() { window.location.reload () });
-  });
-
   // Make the editor's menu to never scroll out of view.
   var bar = $ ("#editorheader").remove ();
   $ ("#workspacemenu").append (bar);
   
-  rangy.init ();
   navigationNewPassage ();
   $ ("#usfmeditor").on ("paste cut keydown", usfmEditorChanged);
   $ (window).on ("unload", usfmEditorUnload);
@@ -83,7 +75,7 @@ var usfmSaving = false;
 
 function navigationNewPassage ()
 {
-  if (typeof navigationBook != 'undefined') {
+  if (is_outside_workspace()) {
     usfmNavigationBook = navigationBook;
     usfmNavigationChapter = navigationChapter;
     usfmNavigationVerse = navigationVerse;
@@ -426,8 +418,12 @@ function usfmPositionCaret (position)
   var currentPosition = usfmGetCaretPosition ();
   if (currentPosition == undefined) return;
   if (position == undefined) return;
-  var selection = rangy.getSelection ();
-  selection.move ("character", position - currentPosition);
+  var selection = document.getSelection();
+  var direction = (position - currentPosition > 0) ? "forward" : "backward";
+  var iterations = Math.abs(position - currentPosition);
+  for (var i = 0; i < iterations; i++) {
+    selection.modify ("move", direction, "character");
+  }
 }
 
 
@@ -497,7 +493,7 @@ function clarifyCaret ()
 
 function editusfmSwipeLeft (event)
 {
-  if (typeof navigateNextChapter != 'undefined') {
+  if (is_outside_workspace()) {
     navigateNextChapter (event);
   } else if (parent.window.navigateNextChapter != 'undefined') {
     parent.window.navigateNextChapter (event);
@@ -507,7 +503,7 @@ function editusfmSwipeLeft (event)
 
 function editusfmSwipeRight (event)
 {
-  if (typeof navigatePreviousChapter != 'undefined') {
+  if (is_outside_workspace()) {
     navigatePreviousChapter (event);
   } else if (parent.window.navigatePreviousChapter != 'undefined') {
     parent.window.navigatePreviousChapter (event);
