@@ -25,6 +25,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define _SILENCE_CXX17_CODECVT_HEADER_DEPRECATION_WARNING 1
 #pragma GCC diagnostic pop
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#include <codecvt>
+#pragma clang diagnostic pop
 #include <filter/string.h>
 #pragma GCC diagnostic push
 #pragma clang diagnostic ignored "-Wimplicit-int-conversion"
@@ -137,7 +141,7 @@ std::string implode (const std::vector <std::string>& values, std::string delimi
 // Example input {1, 2, 3, 4}, max three last bits, the output will be [12, 3, 4}.
 void implode_from_beginning_remain_with_max_n_bits (std::vector<std::string>& input, const int n, const std::string& joiner)
 {
-  while (input.size() > n) {
+  while (static_cast<int>(input.size()) > n) {
     input[1].insert(0, input.at(0) + joiner);
     input.erase(input.cbegin());
   }
@@ -147,11 +151,15 @@ void implode_from_beginning_remain_with_max_n_bits (std::vector<std::string>& in
 // Replaces string contents.
 std::string replace (const std::string& search, const std::string& replace, std::string subject, int * count)
 {
-  size_t offposition {subject.find (search)};
-  while (offposition != std::string::npos) {
-    subject.replace (offposition, search.length (), replace);
-    if (count) (*count)++;
-    offposition = subject.find (search, offposition + replace.length ());
+  if (!search.empty()) {
+    if (!subject.empty()) {
+      size_t offposition {subject.find (search)};
+      while (offposition != std::string::npos) {
+        subject.replace (offposition, search.length (), replace);
+        if (count) (*count)++;
+        offposition = subject.find (search, offposition + replace.length ());
+      }
+    }
   }
   return subject;
 }
@@ -194,9 +202,11 @@ std::string convert_to_string (const std::string& s)
 }
 
 
-std::string convert_to_string (const float f)
+std::string convert_to_string (const float f, const int precision)
 {
   std::ostringstream r;
+  if (precision)
+    r << std::fixed << std::setprecision(precision);
   r << f;
   return r.str();
 }
@@ -1502,7 +1512,7 @@ std::string convert_xml_character_entities_to_characters (std::string data)
     ss >> codepoint;
     
     int cp = codepoint;
-    // Adapted from: http://www.zedwood.com/article/cpp-utf8-char-to-codepoint.
+    // Adapted from: https://www.zedwood.com/article/cpp-utf8-char-to-codepoint.
     char c[5]={ 0x00,0x00,0x00,0x00,0x00 };
     if (cp<=0x7F) {
       c[0] = static_cast<char> (cp);
@@ -2258,4 +2268,47 @@ std::string convert_windows1252_to_utf8 (const std::string& input)
 }
 
 
+void hex_dump (const void* addr, const int len)
+{
+  constexpr const int per_line {16};
+
+  int i;
+  unsigned char buff[per_line+1];
+  const unsigned char* pc = static_cast<const unsigned char*>(addr);
+  
+  // Process every byte in the data.
+  for (i = 0; i < len; i++) {
+    // Multiple of per_line means new or first line (with line offset).
+    
+    if ((i % per_line) == 0) {
+      // Only print previous-line ASCII buffer for lines beyond first.
+      if (i != 0)
+        std::cout << "  " << buff << std::endl;
+      
+      // Output the offset of current line.
+      printf("  %04x ", i);
+    }
+    
+    // Now the hex code for the specific character.
+    printf(" %02x", pc[i]);
+    
+    // And buffer a printable ASCII character for later.
+    if ((pc[i] < 0x20) || (pc[i] > 0x7e)) // isprint() may be better.
+      buff[i % per_line] = '.';
+    else
+      buff[i % per_line] = pc[i];
+    buff[(i % per_line) + 1] = '\0';
+  }
+  
+  // Pad out last line if not exactly per_line characters.
+  while ((i % per_line) != 0) {
+    printf ("   ");
+    i++;
+  }
+  
+  // And print the final ASCII buffer.
+  std::cout << "  " << buff << std::endl;
+}
+
+
 } // Namespace.
