@@ -43,7 +43,7 @@ std::string images_index_url ()
 
 bool images_index_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -58,11 +58,11 @@ std::string images_index (Webserver_Request& webserver_request)
 
   
   // File upload.
-  if (webserver_request.post.count ("upload")) {
+  if (webserver_request.post_count("upload")) {
     const std::string& folder = filter_url_tempfile ();
     filter_url_mkdir (folder);
-    const std::string& file = filter_url_create_path ({folder, webserver_request.post ["filename"]});
-    const std::string& data = webserver_request.post ["data"];
+    const std::string file = filter_url_create_path ({folder, webserver_request.post_get("filename")});
+    const std::string data = webserver_request.post_get("data");
     if (!data.empty ()) {
       filter_url_file_put_contents (file, data);
       const bool background_import = filter_archive_is_archive (file);
