@@ -26,7 +26,7 @@
 #include <filter/string.h>
 #include <filter/archive.h>
 #include <filter/usfm.h>
-#include <dialog/list.h>
+#include <dialog/select.h>
 #include <dialog/entry.h>
 #include <access/bible.h>
 #include <locale/translate.h>
@@ -50,7 +50,7 @@ const char * manage_exports_url ()
 
 bool manage_exports_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -71,28 +71,28 @@ std::string manage_exports (Webserver_Request& webserver_request)
   Assets_View view;
   
   
-  if (webserver_request.query.count ("bible")) {
-    std::string bible = webserver_request.query["bible"];
-    if (bible.empty()) {
-      Dialog_List dialog_list = Dialog_List ("exports", translate("Select a Bible"), "", "");
-      std::vector <std::string> bibles = access_bible::bibles (webserver_request);
-      for (const auto& bible2 : bibles) {
-        dialog_list.add_row (bible2, "bible", bible2);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      webserver_request.database_config_user()->setBible (bible);
+  {
+    constexpr const char* identification {"bible"};
+    if (webserver_request.post_count(identification)) {
+      const auto bible = webserver_request.post_get(identification);
+      webserver_request.database_config_user()->set_bible (bible);
+      view.set_variable ("success", translate("The selected Bible was saved."));
     }
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = access_bible::bibles (webserver_request),
+      .selected = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ()),
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
   }
   
   
-  std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible ());
-  view.set_variable ("bible", bible);
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ());
   
   
-  std::string checkbox = webserver_request.post ["checkbox"];
-  bool checked = filter::strings::convert_to_bool (webserver_request.post ["checked"]);
+  std::string checkbox = webserver_request.post_get("checkbox");
+  bool checked = filter::strings::convert_to_bool (webserver_request.post_get("checked"));
   
   
   if (webserver_request.query.count ("remove")) {
@@ -118,8 +118,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
   }
   
   
-  if (webserver_request.post.count ("emailsubmit")) {
-    std::string email = webserver_request.post["emailentry"];
+  if (webserver_request.post_count("emailsubmit")) {
+    std::string email = webserver_request.post_get("emailentry");
     bool save = false;
     if (email.empty ()) {
       save = true;
@@ -213,8 +213,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("pagewidth")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("pagewidth")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 30) && (value <= 500)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_page_width (bible, std::to_string (value));
@@ -228,8 +228,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("pageheight")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("pageheight")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 40) && (value <= 600)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_page_height (bible, std::to_string (value));
@@ -243,8 +243,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("innermargin")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("innermargin")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 0) && (value <= 100)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_inner_margin (bible, std::to_string (value));
@@ -258,8 +258,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("outermargin")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("outermargin")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 0) && (value <= 100)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_outer_margin (bible, std::to_string (value));
@@ -273,8 +273,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("topmargin")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("topmargin")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 0) && (value <= 100)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_top_margin (bible, std::to_string (value));
@@ -288,8 +288,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("bottommargin")) {
-    int value = filter::strings::convert_to_int (webserver_request.post["entry"]);
+  if (webserver_request.post_count("bottommargin")) {
+    int value = filter::strings::convert_to_int (webserver_request.post_get("entry"));
     if ((value >= 0) && (value <= 100)) {
       Database_State::setExport (bible, 0, export_logic::export_needed);
       database::config::bible::set_bottom_margin (bible, std::to_string (value));
@@ -342,20 +342,21 @@ std::string manage_exports (Webserver_Request& webserver_request)
   }
   view.set_variable ("odtqleft", filter::strings::get_checkbox_status (database::config::bible::get_odt_poetry_verses_left (bible)));
   {
-    const std::vector <std::string> markers = database::styles1::get_markers (styles_logic_standard_sheet ());
-    std::vector <std::string> poetry_styles;
-    for (auto & style : markers) {
-      if (filter::usfm::is_standard_q_poetry (style)) poetry_styles.push_back(style);
+    const std::vector <std::string> markers = database::styles::get_markers (stylesv2::standard_sheet ());
+    std::vector <std::string> poetry_markers;
+    for (const auto& marker : markers) {
+      if (filter::usfm::is_standard_q_poetry (marker))
+        poetry_markers.push_back(marker);
     }
-    view.set_variable("poetrymarkers", filter::strings::implode(poetry_styles, " "));
+    view.set_variable("poetrymarkers", filter::strings::implode(poetry_markers, " "));
   }
 
   
-  if (webserver_request.post.count ("fontsubmit")) {
-    std::string font = webserver_request.post["fontentry"];
+  if (webserver_request.post_count("fontsubmit")) {
+    std::string font = webserver_request.post_get("fontentry");
     Database_State::setExport (bible, 0, export_logic::export_needed);
     database::config::bible::set_export_font (bible, font);
-    view.set_variable ("success", translate("The font for securing exports was saved."));
+    view.set_variable ("success", translate("The font for the exports was saved."));
   }
   view.set_variable ("font", database::config::bible::get_export_font (bible));
 
@@ -406,8 +407,8 @@ std::string manage_exports (Webserver_Request& webserver_request)
   }
   
                      
-  if (webserver_request.post.count ("passwordsubmit")) {
-    std::string password = webserver_request.post["passwordentry"];
+  if (webserver_request.post_count("passwordsubmit")) {
+    std::string password = webserver_request.post_get("passwordentry");
     Database_State::setExport (bible, 0, export_logic::export_needed);
     database::config::bible::set_export_password (bible, password);
     view.set_variable ("success", translate("The password for securing exports was saved."));
