@@ -35,8 +35,7 @@ namespace mimetic
 class Rfc822Header: public std::deque<Field>
 {
 public:
-    struct find_by_name: 
-        public std::unary_function<const Field, bool>
+    struct find_by_name
     {
         find_by_name(const std::string&);
         bool operator()(const Field&) const;
