@@ -43,7 +43,7 @@ std::string notes_edit_url ()
 
 bool notes_edit_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
+  return roles::access_control (webserver_request, roles::consultant);
 }
 
 
@@ -65,13 +65,13 @@ std::string notes_edit (Webserver_Request& webserver_request)
   int identifier;
   const char * identifier_label = "identifier";
   if (webserver_request.query.count (identifier_label)) identifier = filter::strings::convert_to_int (webserver_request.query [identifier_label]);
-  else identifier = filter::strings::convert_to_int (webserver_request.post [identifier_label]);
+  else identifier = filter::strings::convert_to_int (webserver_request.post_get(identifier_label));
   if (identifier) view.set_variable (identifier_label, std::to_string (identifier));
   
   
-  if (webserver_request.post.count ("data")) {
+  if (webserver_request.post_count("data")) {
     // Save note.
-    std::string noteData = webserver_request.post["data"];
+    std::string noteData = webserver_request.post_get("data");
     if (database_notes.identifier_exists (identifier)) {
       std::vector <std::string> lines = filter::strings::explode (noteData, '\n');
       for (size_t i = 0; i < lines.size (); i++) {
@@ -82,7 +82,7 @@ std::string notes_edit (Webserver_Request& webserver_request)
       }
       noteData = filter::strings::implode (lines, "\n");
       notes_logic.setContent (identifier, noteData);
-      std::string url = filter_url_build_http_query (notes_note_url (), "id", std::to_string (identifier));
+      const std::string url = filter_url_build_http_query(notes_note_url(), {{"id", std::to_string (identifier)}});
       // View the updated note.
       redirect_browser (webserver_request, url);
       return std::string();
