@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,13 +24,6 @@ var verseReaderUniqueID = Math.floor (Math.random() * 100000000);
 
 $ (document).ready (function ()
 {
-  // Listens for bibleselect option tags value change to update the loaded Bible.
-  var bibleSelectionElement = document.querySelector ("#bibleselect");
-  bibleSelectionElement.addEventListener ('change', () => {
-    $.post ("index", { bibleselect: bibleSelectionElement.value })
-      .done (function() { window.location.reload () });
-  });
-
   // Make the editor's menu to never scroll out of view.
   var bar = $ ("#editorheader").remove ();
   $ ("#workspacemenu").append (bar);
@@ -107,7 +100,7 @@ var readchooseLoadAjaxRequest;
 
 function navigationNewPassage ()
 {
-  if (typeof navigationBook != 'undefined') {
+  if (is_outside_workspace()) {
     readchooseNavigationBook = navigationBook;
     readchooseNavigationChapter = navigationChapter;
     readchooseNavigationVerse = navigationVerse;
@@ -378,7 +371,7 @@ function readChooseGotoResources ()
 
 function readchooseSwipeLeft (event)
 {
-  if (typeof navigateNextVerse != 'undefined') {
+  if (is_outside_workspace()) {
     navigateNextVerse (event);
   } else if (parent.window.navigateNextVerse != 'undefined') {
     parent.window.navigateNextVerse (event);
@@ -388,7 +381,7 @@ function readchooseSwipeLeft (event)
 
 function readchooseSwipeRight (event)
 {
-  if (typeof navigatePreviousVerse != 'undefined') {
+  if (is_outside_workspace()) {
     navigatePreviousVerse (event);
   } else if (parent.window.navigatePreviousVerse != 'undefined') {
     parent.window.navigatePreviousVerse (event);
