@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 std::string read_load_url ();
-bool read_load_acl (void * webserver_request);
-std::string read_load (void * webserver_request);
+bool read_load_acl (Webserver_Request& webserver_request);
+std::string read_load (Webserver_Request& webserver_request);
