@@ -44,7 +44,7 @@ std::string resource_bible2resource_url ()
 
 bool resource_bible2resource_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 }
 
 
