@@ -40,7 +40,7 @@ bool resource_unload_acl (Webserver_Request& webserver_request)
 std::string resource_unload (Webserver_Request& webserver_request)
 {
   // The scroll position of the resource window.
-  int position = filter::strings::convert_to_int (webserver_request.post ["position"]);
+  int position = filter::strings::convert_to_int (webserver_request.post_get("position"));
   if (position < 0) position = 0;
   if (position > 5000) position = 5000;
   // Store the position in volatile memory so it gets retained while the app is on,
