@@ -18,7 +18,6 @@
 
 
 #include <resource/user1edit.h>
-#include <resource/img.h>
 #include <assets/view.h>
 #include <assets/page.h>
 #include <assets/header.h>
@@ -46,7 +45,7 @@ std::string resource_user1edit_url ()
 
 bool resource_user1edit_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 }
 
 
@@ -64,8 +63,8 @@ std::string resource_user1edit (Webserver_Request& webserver_request)
   view.set_variable ("name", name);
   
 
-  if (webserver_request.post.count ("submit")) {
-    std::string data = webserver_request.post["data"];
+  if (webserver_request.post_count("submit")) {
+    std::string data = webserver_request.post_get("data");
     std::vector <std::string> lines = filter::strings::explode (data, '\n');
     int count = 0;
     int bookcount = 0;
