@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2024 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -45,14 +45,6 @@ $(document).ready (function () {
   $ ("#searchresults").on ("click", function (event) {
     handleClick (event);
   });
-  
-  // Listens for bibleselect option tags value change to update the active Bible.
-  var bibleSelectionElement = document.querySelector ("#bibleselect");
-  bibleSelectionElement.addEventListener ('change', () => {
-    $.post ("replace2", { bibleselect: bibleSelectionElement.value })
-    .done (function() { window.location.reload () });
-  });
-  
 });
 
 
