@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -22,11 +22,12 @@
 #include <config/libraries.h>
 
 class Webserver_Request;
+namespace stylesv2 { struct Style; }
 
 class Styles_Css
 {
 public:
-  Styles_Css (Webserver_Request& webserver_request, const std::string & stylesheet);
+  Styles_Css (const std::string& stylesheet);
   Styles_Css(const Styles_Css&) = delete;
   Styles_Css operator=(const Styles_Css&) = delete;
   void editor ();
@@ -35,13 +36,12 @@ public:
   std::string css (std::string path = std::string());
   void customize (const std::string& bible);
 private:
-  Webserver_Request& m_webserver_request;
   std::string m_stylesheet {};
   std::vector <std::string> m_code {};
   bool editor_enabled {false}; // Whether to generate CSS for the Bible text editor.
   bool exports_enabled {false}; // Whether to generate CSS for exported Bibles.
-  void evaluate (void * database_styles_item);
-  void add (void * database_styles_item, bool paragraph, bool keepwithnext);
+  void evaluate (const stylesv2::Style* style);
+  void add (const stylesv2::Style* style, const bool paragraph, const bool keep_with_next);
   void add_exports_styles ();
   void add_editor_styles ();
 };
