@@ -45,7 +45,6 @@ constexpr const auto sync_resources {"syncresources"};
 constexpr const auto clean_demo {"cleandemo"};
 constexpr const auto convert_bible_to_resource {"convertbible2resource"};
 constexpr const auto convert_resource_to_bible {"convertresource2bible"};
-constexpr const auto print_resources {"printresources"};
 constexpr const auto notes_statistics {"notesstatistics"};
 constexpr const auto generate_changes {"generatechanges"};
 constexpr const auto sprint_burndown {"sprintburndown"};
@@ -60,10 +59,8 @@ constexpr const auto export_web_main {"exportwebmain"};
 constexpr const auto export_web_index {"exportwebindex"};
 constexpr const auto export_online_bible {"exportonlinebible"};
 constexpr const auto export_esword {"exportesword"};
-constexpr const auto hyphenate {"hyphenate"};
 constexpr const auto setup_paratext {"setupparatext"};
 constexpr const auto sync_paratext {"syncparatext"};
-constexpr const auto import_images {"importimages"};
 constexpr const auto refresh_sword_modules {"refreshswordmodules"};
 constexpr const auto install_sword_module {"installswordmodule"};
 constexpr const auto update_sword_modules {"updateallswordmodules"};
