@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,8 +21,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-bool http_parse_header (std::string header, void * webserver_request);
-void http_parse_post (std::string content, void * webserver_request);
-void http_assemble_response (void * webserver_request);
-void http_stream_file (void * webserver_request, bool enable_cache);
+class Webserver_Request;
+
+constexpr const char* application_x_www_form_urlencoded {"application/x-www-form-urlencoded"};
+constexpr const char* text_plain {"text/plain"};
+constexpr const char* multipart_form_data {"multipart/form-data"};
+
+bool http_parse_header (std::string header, Webserver_Request& webserver_request);
+void http_parse_post (std::string content, Webserver_Request& webserver_request);
+void http_assemble_response (Webserver_Request& webserver_request);
+void http_stream_file (Webserver_Request& webserver_request, bool enable_cache);
 std::string http_parse_host (const std::string & line);
