@@ -221,7 +221,7 @@ static void webserver_process_request (const int connfd, const std::string& clie
         if (connection_healthy) {
           
           http_parse_post (postdata, request);
-          
+
           // Assemble response.
           bootstrap_index (request);
           http_assemble_response (request);
@@ -880,7 +880,6 @@ void https_server ()
   mbedtls_ctr_drbg_context ctr_drbg;
   mbedtls_ctr_drbg_init (&ctr_drbg);
 
-#if MBEDTLS_VERSION_MAJOR == 3
   const psa_status_t psa_status = psa_crypto_init();
 #pragma GCC diagnostic push
 #pragma clang diagnostic ignored "-Wold-style-cast"
@@ -889,18 +888,12 @@ void https_server ()
     Database_Logs::log("Failure to run PSA crypto initialization: Not running the secure server");
     return;
   }
-#endif
 
   // Load the private RSA server key.
   mbedtls_pk_context pkey;
   mbedtls_pk_init (&pkey);
   int ret =
-#if MBEDTLS_VERSION_MAJOR == 2
-  mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr);
-#endif
-#if MBEDTLS_VERSION_MAJOR == 3
   mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr, mbedtls_ctr_drbg_random, &ctr_drbg);
-#endif
   if (ret != 0) {
     filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     Database_Logs::log("Invalid " + server_key_path + " so not running secure server");
@@ -1001,9 +994,7 @@ void https_server ()
   mbedtls_ssl_cache_free (&cache);
   mbedtls_ctr_drbg_free (&ctr_drbg);
   mbedtls_entropy_free (&entropy);
-#if MBEDTLS_VERSION_MAJOR == 3
   mbedtls_psa_crypto_free();
-#endif
   
 #endif // ifdef RUN_SECURE_SERVER
 }
@@ -1015,7 +1006,7 @@ void https_server ()
  
  In case a client can only connect through port 80, 
  then this may proxy a certain folder to another port:
- http://serverfault.com/questions/472482/proxypass-redirect-directory-url-to-non-standard-port
+ https://serverfault.com/questions/472482/proxypass-redirect-directory-url-to-non-standard-port
  
  Or to write our own server in C acting as a proxy 
  to forward incoming requests to the bibledit instances on localhost.
