@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ std::string workspace_index_url ()
 
 bool workspace_index_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
+  return roles::access_control (webserver_request, roles::consultant);
 }
 
 
@@ -55,17 +55,17 @@ std::string workspace_index (Webserver_Request& webserver_request)
     const size_t bench = static_cast <size_t> (filter::strings::convert_to_int (webserver_request.query ["bench"]));
     if (bench < workspaces.size ()) {
       const std::string workspace = workspaces [bench];
-      webserver_request.database_config_user()->setActiveWorkspace (workspace);
+      webserver_request.database_config_user()->set_active_workspace (workspace);
     }
   }
   
   
   // Check that the active workspace exists, else set the first available workspace as the active one.
   {
-    const std::string workspace = webserver_request.database_config_user ()->getActiveWorkspace ();
+    const std::string workspace = webserver_request.database_config_user ()->get_active_workspace ();
     if (!in_array (workspace, workspaces)) {
       if (!workspaces.empty ()) {
-        webserver_request.database_config_user ()->setActiveWorkspace (workspaces [0]);
+        webserver_request.database_config_user ()->set_active_workspace (workspaces [0]);
       }
     }
   }
@@ -89,7 +89,7 @@ std::string workspace_index (Webserver_Request& webserver_request)
     const std::vector <Passage> passages = database_notes.get_passages (note_id);
     if (!passages.empty ()) {
       Ipc_Focus::set (webserver_request, passages[0].m_book, passages[0].m_chapter, filter::strings::convert_to_int (passages[0].m_verse));
-      Navigation_Passage::record_history (webserver_request, passages[0].m_book, passages[0].m_chapter, filter::strings::convert_to_int (passages[0].m_verse));
+      navigation_passage::record_history (webserver_request, passages[0].m_book, passages[0].m_chapter, filter::strings::convert_to_int (passages[0].m_verse));
     }
   }
   
@@ -104,7 +104,7 @@ std::string workspace_index (Webserver_Request& webserver_request)
   
   std::map <int, std::string> urls = workspace_get_urls (webserver_request, true);
   std::map <int, std::string> widths = workspace_get_widths (webserver_request);
-  // The Bible editor number, starting from 1, going up.
+  // The Bible editor number, starting from 1, increasing.
   std::map <int, int> editor_numbers = workspace_add_bible_editor_number (urls);
   for (int key = 0; key < 15; key++) {
     const std::string url = urls [key];
@@ -142,6 +142,16 @@ std::string workspace_index (Webserver_Request& webserver_request)
   view.set_variable ("workspacewidth", workspacewidth);
   
   
+  // When the URLs loaded specify a Bible, then set this as the active Bible.
+  // Extract the first Bible, if any, to do that.
+  // See https://github.com/bibledit/cloud/issues/1004 for more info.
+  {
+    std::optional<std::string> bible = get_first_bible_from_urls (urls);
+    if (bible)
+      webserver_request.database_config_user()->set_bible(bible.value());
+  }
+  
+  
   // The rendered template disables framekillers through the "sandbox" attribute on the iframe elements.
   page += view.render ("workspace", "index");
   page += assets_page::footer ();
