@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -42,14 +42,14 @@ std::string workspace_settings_url ()
 
 bool workspace_settings_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
+  return roles::access_control (webserver_request, roles::consultant);
 }
 
 
 std::string workspace_settings (Webserver_Request& webserver_request)
 {
   std::string name = webserver_request.query ["name"];
-  webserver_request.database_config_user()->setActiveWorkspace (name);
+  webserver_request.database_config_user()->set_active_workspace (name);
   
   if (webserver_request.query.count ("preset")) {
     int preset = filter::strings::convert_to_int (webserver_request.query ["preset"]);
@@ -58,7 +58,7 @@ std::string workspace_settings (Webserver_Request& webserver_request)
     workspace_set_heights (webserver_request, workspace_get_default_heights (preset));
   }
   
-  if (webserver_request.post.count ("save")) {
+  if (webserver_request.post_count("save")) {
     std::map <int, std::string> urls;
     std::map <int, std::string> widths;
     std::map <int, std::string> row_heights;
@@ -67,12 +67,12 @@ std::string workspace_settings (Webserver_Request& webserver_request)
     for (int row = 1; row <= 3; row++) {
       for (int column = 1; column <= 5; column++) {
         std::string key = std::to_string (row) + std::to_string (column);
-        urls [to14] = webserver_request.post ["url" + key];
-        widths [to14] = webserver_request.post ["width" + key];
+        urls [to14] = webserver_request.post_get("url" + key);
+        widths [to14] = webserver_request.post_get("width" + key);
         to14++;
       }
       std::string key = std::to_string (row);
-      row_heights [to2] = webserver_request.post ["height" + key];
+      row_heights [to2] = webserver_request.post_get("height" + key);
       to2++;
     }
     workspace_set_urls (webserver_request, urls);
@@ -80,7 +80,7 @@ std::string workspace_settings (Webserver_Request& webserver_request)
     workspace_set_heights (webserver_request, row_heights);
     // If no "px" or "%" is given, then default to "%".
     // https://github.com/bibledit/cloud/issues/643
-    std::string workspacewidth = filter::strings::trim(webserver_request.post ["workspacewidth"]);\
+    std::string workspacewidth = filter::strings::trim(webserver_request.post_get("workspacewidth"));
     if (!workspacewidth.empty()) {
       size_t pos_px = workspacewidth.find ("px");
       size_t pos_pct = workspacewidth.find ("%");
